/// <reference types="node" />
export declare type Message = Buffer | string;
export interface Secret {
    message: Message;
    passphrase: string;
}
export declare type Kdf = (passphrase: string, salt: string) => Promise<Buffer>;
export interface Block {
    salt: Buffer;
    iv: Buffer;
    headers: Buffer;
    data: Buffer;
}
/**
 * Get data length of message
 * @param message message
 * @returns data length
 */
export declare const getDataLength: (message: Message) => number;
/**
 * Encrypt secrets using Blockcrypt
 * @param secrets secrets
 * @param kdf key derivation function
 * @param headersLength optional, headers length in increments of `8` (defaults to `64`)
 * @param dataLength optional, data length in increments of `8` (defaults to first secret ciphertext buffer length * 2 rounded to nearest upper increment of `64`)
 * @param salt optional, salt used for deterministic unit tests
 * @param iv optional, initialization vector used for deterministic unit tests
 * @returns block
 */
export declare const encrypt: (secrets: Secret[], kdf: Kdf, headersLength?: number, dataLength?: number, salt?: Buffer, iv?: Buffer) => Promise<Block>;
/**
 * Decrypt secret encrypted using Blockcrypt
 * @param passphrase passphrase
 * @param salt salt
 * @param iv initialization vector
 * @param headers headers
 * @param data data
 * @param kdf key derivation function
 * @returns message
 */
export declare const decrypt: (passphrase: string, salt: Buffer, iv: Buffer, headers: Buffer, data: Buffer, kdf: Kdf) => Promise<Buffer>;
